==> qtjambi-datavisualization-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiDataVisualization/Q3DObject_shell.h <==
#ifndef Q3DOBJECT_SHELL_H
#define Q3DOBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/q3dobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qvector3d.h>
#include <QtJambi/RegistryAPI>


class Q3DObject_shell : public QtDataVisualization::Q3DObject, public QtJambiShellInterface
{
public:
    Q3DObject_shell(QObject* parent0 = nullptr);
    ~Q3DObject_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void copyValuesFrom(const QtDataVisualization::Q3DObject& source0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct Q3DObject_access : public QtDataVisualization::Q3DObject
{
    jboolean __qt_isDirty(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setDirty_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean dirty0);
    void __qt_copyValuesFrom_cref_QtDataVisualization_Q3DObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source0);
};

#endif // Q3DOBJECT_SHELL_H

==> qtjambi-datavisualization-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiDataVisualization/Q3DObject_shell.h <==
#ifndef Q3DOBJECT_SHELL_H
#define Q3DOBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/q3dobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qvectornd.h>
#include <QtJambi/RegistryAPI>


class Q3DObject_shell : public Q3DObject, public QtJambiShellInterface
{
public:
    Q3DObject_shell(QObject* parent0 = nullptr);
    ~Q3DObject_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void copyValuesFrom(const Q3DObject& source0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct Q3DObject_access : public Q3DObject
{
    jboolean __qt_isDirty(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setDirty_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean dirty0);
    void __qt_copyValuesFrom_cref_Q3DObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source0);
};

#endif // Q3DOBJECT_SHELL_H
